package AsposePdfCloud::Object::Signature;

require 5.6.0;
use strict;
use warnings;
use utf8;
use JSON qw(decode_json);
use Data::Dumper;
use Module::Runtime qw(use_module);
use Log::Any qw($log);
use Date::Parse;
use DateTime;

use base "AsposePdfCloud::Object::BaseObject";

#
#
#
#NOTE: This class is auto generated by the swagger code generator program. Do not edit the class manually.
#

my $swagger_types = {
    'SignaturePath' => 'string',
    'SignatureType' => 'string',
    'Password' => 'string',
    'Contact' => 'string',
    'Location' => 'string',
    'Visible' => 'boolean',
    'Rectangle' => 'Rectangle',
    'FormFieldName' => 'string',
    'Authority' => 'string',
    'Date' => 'string'
};

my $attribute_map = {
    'SignaturePath' => 'SignaturePath',
    'SignatureType' => 'SignatureType',
    'Password' => 'Password',
    'Contact' => 'Contact',
    'Location' => 'Location',
    'Visible' => 'Visible',
    'Rectangle' => 'Rectangle',
    'FormFieldName' => 'FormFieldName',
    'Authority' => 'Authority',
    'Date' => 'Date'
};

# new object
sub new { 
    my ($class, %args) = @_; 
    my $self = { 
        #
        'SignaturePath' => $args{'SignaturePath'}, 
        #
        'SignatureType' => $args{'SignatureType'}, 
        #
        'Password' => $args{'Password'}, 
        #
        'Contact' => $args{'Contact'}, 
        #
        'Location' => $args{'Location'}, 
        #
        'Visible' => $args{'Visible'}, 
        #
        'Rectangle' => $args{'Rectangle'}, 
        #
        'FormFieldName' => $args{'FormFieldName'}, 
        #
        'Authority' => $args{'Authority'}, 
        #
        'Date' => $args{'Date'}
    }; 

    return bless $self, $class; 
}  

# get swagger type of the attribute
sub get_swagger_types {
    return $swagger_types;
}

# get attribute mappping
sub get_attribute_map {
    return $attribute_map;
}

1;
